==> jc-1.4.0.tar.gz: soot/util/JimpleInputStream.h <==
// public class soot.util.JimpleInputStream

// class file dependencies
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f39b2c829999c2fb soot_util_JimpleInputStream
// @dep_class ce4d97b1a0c5a527 soot_util_SootInputStream

// header file dependencies
// @dep_header soot_util_SootInputStream

#include "soot/util/SootInputStream.h"

#ifndef _JC_soot_util_JimpleInputStream_H_
#define _JC_soot_util_JimpleInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_util_JimpleInputStream$sub_refs	_jc_soot_util_JimpleInputStream$sub_refs;
typedef struct _jc_soot_util_JimpleInputStream$sub_nonrefs	_jc_soot_util_JimpleInputStream$sub_nonrefs;
typedef struct _jc_soot_util_JimpleInputStream$refs	_jc_soot_util_JimpleInputStream$refs;
typedef struct _jc_soot_util_JimpleInputStream$nonrefs	_jc_soot_util_JimpleInputStream$nonrefs;
typedef struct _jc_soot_util_JimpleInputStream$object	_jc_soot_util_JimpleInputStream$object;

typedef const struct _jc_soot_util_JimpleInputStream$vmethods	_jc_soot_util_JimpleInputStream$vmethods;
typedef const struct _jc_soot_util_JimpleInputStream$vtable	_jc_soot_util_JimpleInputStream$vtable;
typedef const struct _jc_soot_util_JimpleInputStream$vtype	_jc_soot_util_JimpleInputStream$vtype;

// Constructors
extern void _jc_soot_util_JimpleInputStream$method$_init$3887600c17c5e554(_jc_env *, struct _jc_soot_util_JimpleInputStream$object *, struct _jc_java_io_InputStream$object *);

// Virtual methods structure
struct _jc_soot_util_JimpleInputStream$vmethods {
};

// Vtable
struct _jc_soot_util_JimpleInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_soot_util_SootInputStream$vmethods	soot_util_SootInputStream;
	_jc_soot_util_JimpleInputStream$vmethods	soot_util_JimpleInputStream;
};

// Vtype
struct _jc_soot_util_JimpleInputStream$vtype {
	_jc_type			type;
	_jc_soot_util_JimpleInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_JimpleInputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_util_JimpleInputStream$refs {
    _jc_soot_util_JimpleInputStream$sub_refs	soot_util_JimpleInputStream;
    _jc_soot_util_SootInputStream$sub_refs	soot_util_SootInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_JimpleInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_JimpleInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_soot_util_SootInputStream$sub_nonrefs	soot_util_SootInputStream;
    _jc_soot_util_JimpleInputStream$sub_nonrefs	soot_util_JimpleInputStream;
};

// Object instance structure
struct _jc_soot_util_JimpleInputStream$object {
	_jc_soot_util_JimpleInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_JimpleInputStream$vtype	*vtype;
	_jc_soot_util_JimpleInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_JimpleInputStream$vtype _jc_soot_util_JimpleInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_JimpleInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_JimpleInputStream$class_object;

#endif	/* _JC_soot_util_JimpleInputStream_H_ */

==> jc-1.4.6.tar.gz: soot/util/JimpleInputStream.h <==
// public class soot.util.JimpleInputStream

// class file dependencies
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f39b2c829999c2fb soot_util_JimpleInputStream
// @dep_class ce4d97b1a0c5a527 soot_util_SootInputStream

// header file dependencies
// @dep_header soot_util_SootInputStream

#include "soot/util/SootInputStream.h"

#ifndef _JC_soot_util_JimpleInputStream_H_
#define _JC_soot_util_JimpleInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_util_JimpleInputStream$sub_refs	_jc_soot_util_JimpleInputStream$sub_refs;
typedef struct _jc_soot_util_JimpleInputStream$sub_nonrefs	_jc_soot_util_JimpleInputStream$sub_nonrefs;
typedef struct _jc_soot_util_JimpleInputStream$refs	_jc_soot_util_JimpleInputStream$refs;
typedef struct _jc_soot_util_JimpleInputStream$nonrefs	_jc_soot_util_JimpleInputStream$nonrefs;
typedef struct _jc_soot_util_JimpleInputStream$object	_jc_soot_util_JimpleInputStream$object;

typedef const struct _jc_soot_util_JimpleInputStream$vmethods	_jc_soot_util_JimpleInputStream$vmethods;
typedef const struct _jc_soot_util_JimpleInputStream$vtable	_jc_soot_util_JimpleInputStream$vtable;
typedef const struct _jc_soot_util_JimpleInputStream$vtype	_jc_soot_util_JimpleInputStream$vtype;

// Constructors
extern void _jc_soot_util_JimpleInputStream$method$_init$3887600c17c5e554(_jc_env *, struct _jc_soot_util_JimpleInputStream$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_util_JimpleInputStream$vmethods {
};

// Vtable
struct _jc_soot_util_JimpleInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_soot_util_SootInputStream$vmethods	soot_util_SootInputStream;
	_jc_soot_util_JimpleInputStream$vmethods	soot_util_JimpleInputStream;
};

// Vtype
struct _jc_soot_util_JimpleInputStream$vtype {
	_jc_type			type;
	_jc_soot_util_JimpleInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_JimpleInputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_util_JimpleInputStream$refs {
    _jc_soot_util_JimpleInputStream$sub_refs	soot_util_JimpleInputStream;
    _jc_soot_util_SootInputStream$sub_refs	soot_util_SootInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_JimpleInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_JimpleInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_soot_util_SootInputStream$sub_nonrefs	soot_util_SootInputStream;
    _jc_soot_util_JimpleInputStream$sub_nonrefs	soot_util_JimpleInputStream;
};

// Object instance structure
struct _jc_soot_util_JimpleInputStream$object {
	_jc_soot_util_JimpleInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_JimpleInputStream$vtype	*vtype;
	_jc_soot_util_JimpleInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_JimpleInputStream$vtype _jc_soot_util_JimpleInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_JimpleInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_JimpleInputStream$class_object;

#endif	/* _JC_soot_util_JimpleInputStream_H_ */
